==> ph-xsds-xades132-2.6.0-sources.jar: com/helger/xsds/xades132/SignerRoleV2Type.java <==

package com.helger.xsds.xades132;

import java.io.Serializable;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableCopy;
import com.helger.commons.equals.EqualsHelper;
import com.helger.commons.hashcode.HashCodeGenerator;
import com.helger.commons.lang.IExplicitlyCloneable;
import com.helger.commons.string.ToStringGenerator;


/**
 * <p>Java class for SignerRoleV2Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SignerRoleV2Type"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://uri.etsi.org/01903/v1.3.2#}ClaimedRoles" minOccurs="0"/&gt;
 *         &lt;element ref="{http://uri.etsi.org/01903/v1.3.2#}CertifiedRolesV2" minOccurs="0"/&gt;
 *         &lt;element ref="{http://uri.etsi.org/01903/v1.3.2#}SignedAssertions" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * <p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-equalshashcode</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-tostring</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-cloneable2</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-value-extender</p>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SignerRoleV2Type", propOrder = {
    "claimedRoles",
    "certifiedRolesV2",
    "signedAssertions"
})
@CodingStyleguideUnaware
public class SignerRoleV2Type implements Serializable, IExplicitlyCloneable
{

    @XmlElement(name = "ClaimedRoles")
    private ClaimedRolesListType claimedRoles;
    @XmlElement(name = "CertifiedRolesV2")
    private CertifiedRolesListTypeV2 certifiedRolesV2;
    @XmlElement(name = "SignedAssertions")
    private SignedAssertionsListType signedAssertions;

    /**
     * Default constructor<br>
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     */
    public SignerRoleV2Type() {
    }

    /**
     * Gets the value of the claimedRoles property.
     * 
     * @return
     *     possible object is
     *     {@link ClaimedRolesListType }
     *     
     */
    @Nullable
    public ClaimedRolesListType getClaimedRoles() {
        return claimedRoles;
    }

    /**
     * Sets the value of the claimedRoles property.
     * 
     * @param value
     *     allowed object is
     *     {@link ClaimedRolesListType }
     *     
     */
    public void setClaimedRoles(
        @Nullable
        ClaimedRolesListType value) {
        this.claimedRoles = value;
    }

    /**
     * Gets the value of the certifiedRolesV2 property.
     * 
     * @return
     *     possible object is
     *     {@link CertifiedRolesListTypeV2 }
     *     
     */
    @Nullable
    public CertifiedRolesListTypeV2 getCertifiedRolesV2() {
        return certifiedRolesV2;
    }

    /**
     * Sets the value of the certifiedRolesV2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link CertifiedRolesListTypeV2 }
     *     
     */
    public void setCertifiedRolesV2(
        @Nullable
        CertifiedRolesListTypeV2 value) {
        this.certifiedRolesV2 = value;
    }

    /**
     * Gets the value of the signedAssertions property.
     * 
     * @return
     *     possible object is
     *     {@link SignedAssertionsListType }
     *     
     */
    @Nullable
    public SignedAssertionsListType getSignedAssertions() {
        return signedAssertions;
    }

    /**
     * Sets the value of the signedAssertions property.
     * 
     * @param value
     *     allowed object is
     *     {@link SignedAssertionsListType }
     *     
     */
    public void setSignedAssertions(
        @Nullable
        SignedAssertionsListType value) {
        this.signedAssertions = value;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        if (o == this) {
            return true;
        }
        if ((o == null)||(!getClass().equals(o.getClass()))) {
            return false;
        }
        final SignerRoleV2Type rhs = ((SignerRoleV2Type) o);
        if (!EqualsHelper.equals(certifiedRolesV2, rhs.certifiedRolesV2)) {
            return false;
        }
        if (!EqualsHelper.equals(claimedRoles, rhs.claimedRoles)) {
            return false;
        }
        if (!EqualsHelper.equals(signedAssertions, rhs.signedAssertions)) {
            return false;
        }
        return true;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return new HashCodeGenerator(this).append(certifiedRolesV2).append(claimedRoles).append(signedAssertions).getHashCode();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-tostring
     * 
     */
    @Override
    public String toString() {
        return new ToStringGenerator(this).append("certifiedRolesV2", certifiedRolesV2).append("claimedRoles", claimedRoles).append("signedAssertions", signedAssertions).getToString();
    }

    /**
     * This method clones all values from <code>this</code> to the passed object. All data in the parameter object is overwritten!Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @param ret
     *     The target object to clone to. May not be <code>null</code>.
     */
    public void cloneTo(
        @Nonnull
        SignerRoleV2Type ret) {
        ret.certifiedRolesV2 = ((certifiedRolesV2 == null)?null:certifiedRolesV2 .clone());
        ret.claimedRoles = ((claimedRoles == null)?null:claimedRoles.clone());
        ret.signedAssertions = ((signedAssertions == null)?null:signedAssertions.clone());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @return
     *     The cloned object. Never <code>null</code>.
     */
    @Nonnull
    @ReturnsMutableCopy
    @Override
    public SignerRoleV2Type clone() {
        SignerRoleV2Type ret = new SignerRoleV2Type();
        cloneTo(ret);
        return ret;
    }

}

==> ph-xsds-xades132-3.0.0-sources.jar: com/helger/xsds/xades132/SignerRoleV2Type.java <==

package com.helger.xsds.xades132;

import java.io.Serializable;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableCopy;
import com.helger.commons.equals.EqualsHelper;
import com.helger.commons.hashcode.HashCodeGenerator;
import com.helger.commons.lang.IExplicitlyCloneable;
import com.helger.commons.string.ToStringGenerator;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SignerRoleV2Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SignerRoleV2Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://uri.etsi.org/01903/v1.3.2#}ClaimedRoles" minOccurs="0"/>
 *         <element ref="{http://uri.etsi.org/01903/v1.3.2#}CertifiedRolesV2" minOccurs="0"/>
 *         <element ref="{http://uri.etsi.org/01903/v1.3.2#}SignedAssertions" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * <p>This class was annotated by ph-jaxb-plugin -Xph-annotate</p>
 * <p>This class contains methods created by ph-jaxb-plugin -Xph-equalshashcode</p>
 * <p>This class contains methods created by ph-jaxb-plugin -Xph-tostring</p>
 * <p>This class contains methods created by ph-jaxb-plugin -Xph-cloneable2</p>
 * <p>This class contains methods created by ph-jaxb-plugin -Xph-value-extender</p>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SignerRoleV2Type", propOrder = {
    "claimedRoles",
    "certifiedRolesV2",
    "signedAssertions"
})
@CodingStyleguideUnaware
public class SignerRoleV2Type implements Serializable, IExplicitlyCloneable
{

    @XmlElement(name = "ClaimedRoles")
    private ClaimedRolesListType claimedRoles;
    @XmlElement(name = "CertifiedRolesV2")
    private CertifiedRolesListTypeV2 certifiedRolesV2;
    @XmlElement(name = "SignedAssertions")
    private SignedAssertionsListType signedAssertions;

    /**
     * Default constructor<br>
     * Note: automatically created by ph-jaxb-plugin -Xph-value-extender
     * 
     */
    public SignerRoleV2Type() {
    }

    /**
     * Gets the value of the claimedRoles property.
     * 
     * @return
     *     possible object is
     *     {@link ClaimedRolesListType }
     *     
     */
    @Nullable
    public ClaimedRolesListType getClaimedRoles() {
        return claimedRoles;
    }

    /**
     * Sets the value of the claimedRoles property.
     * 
     * @param value
     *     allowed object is
     *     {@link ClaimedRolesListType }
     *     
     */
    public void setClaimedRoles(
        @Nullable
        ClaimedRolesListType value) {
        this.claimedRoles = value;
    }

    /**
     * Gets the value of the certifiedRolesV2 property.
     * 
     * @return
     *     possible object is
     *     {@link CertifiedRolesListTypeV2 }
     *     
     */
    @Nullable
    public CertifiedRolesListTypeV2 getCertifiedRolesV2() {
        return certifiedRolesV2;
    }

    /**
     * Sets the value of the certifiedRolesV2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link CertifiedRolesListTypeV2 }
     *     
     */
    public void setCertifiedRolesV2(
        @Nullable
        CertifiedRolesListTypeV2 value) {
        this.certifiedRolesV2 = value;
    }

    /**
     * Gets the value of the signedAssertions property.
     * 
     * @return
     *     possible object is
     *     {@link SignedAssertionsListType }
     *     
     */
    @Nullable
    public SignedAssertionsListType getSignedAssertions() {
        return signedAssertions;
    }

    /**
     * Sets the value of the signedAssertions property.
     * 
     * @param value
     *     allowed object is
     *     {@link SignedAssertionsListType }
     *     
     */
    public void setSignedAssertions(
        @Nullable
        SignedAssertionsListType value) {
        this.signedAssertions = value;
    }

    /**
     * Created by ph-jaxb-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        if (o == this) {
            return true;
        }
        if ((o == null)||(!getClass().equals(o.getClass()))) {
            return false;
        }
        final SignerRoleV2Type rhs = ((SignerRoleV2Type) o);
        if (!EqualsHelper.equals(certifiedRolesV2, rhs.certifiedRolesV2)) {
            return false;
        }
        if (!EqualsHelper.equals(claimedRoles, rhs.claimedRoles)) {
            return false;
        }
        if (!EqualsHelper.equals(signedAssertions, rhs.signedAssertions)) {
            return false;
        }
        return true;
    }

    /**
     * Created by ph-jaxb-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return new HashCodeGenerator(this).append(certifiedRolesV2).append(claimedRoles).append(signedAssertions).getHashCode();
    }

    /**
     * Created by ph-jaxb-plugin -Xph-tostring
     * 
     */
    @Override
    public String toString() {
        return new ToStringGenerator(this).append("certifiedRolesV2", certifiedRolesV2).append("claimedRoles", claimedRoles).append("signedAssertions", signedAssertions).getToString();
    }

    /**
     * This method clones all values from <code>this</code> to the passed object. All data in the parameter object is overwritten!Created by ph-jaxb-plugin -Xph-cloneable2
     * 
     * @param ret
     *     The target object to clone to. May not be <code>null</code>.
     */
    public void cloneTo(
        @Nonnull
        SignerRoleV2Type ret) {
        ret.certifiedRolesV2 = ((certifiedRolesV2 == null)?null:certifiedRolesV2 .clone());
        ret.claimedRoles = ((claimedRoles == null)?null:claimedRoles.clone());
        ret.signedAssertions = ((signedAssertions == null)?null:signedAssertions.clone());
    }

    /**
     * Created by ph-jaxb-plugin -Xph-cloneable2
     * 
     * @return
     *     The cloned object. Never <code>null</code>.
     */
    @Nonnull
    @ReturnsMutableCopy
    @Override
    public SignerRoleV2Type clone() {
        SignerRoleV2Type ret = new SignerRoleV2Type();
        cloneTo(ret);
        return ret;
    }

}
